@@ -19,7 +19,8 @@ from requests_oauthlib import OAuth2Session
 from . import utils, entity_json
 from .dataset import Dataset
 from .exceptions import PipeAlreadyExists, SystemAlreadyExists, ConfigUploadFailed, \
-    TimeoutWhileWaitingForBackupToFinishException, ServiceUnavailable, InternalServerError, BadRequestException
+    TimeoutWhileWaitingForBackupToFinishException, ServiceUnavailable, InternalServerError, BadRequestException, \
+    TimeoutWhileWaitingForRestoreToFinishException
 from .log import Log
 from .pipe import Pipe
 from .system import System
@@ -1157,6 +1158,44 @@ class Connection:
                 raise TimeoutWhileWaitingForBackupToFinishException(
                     "Timed out while waiting for the backup to finish running! lat backup_info:\n%s" % (
                         backup_info,))
+            time.sleep(poll_interval)
+
+    def trigger_restore(self, node_id_regexp, target_backup_time):
+        url = self.sesamapi_base_url + "restores"
+        response = self.do_post_request(url, allowable_response_status_codes=[200],
+                                        data={
+                                            "node_id_regexp": node_id_regexp,
+                                            "target_backup_time": target_backup_time,
+                                        })
+        restore_info = response.json()
+        return restore_info
+
+    def wait_for_restore_to_finish(self, restore_id, timeout=600, poll_interval=0.5, **kwargs):
+        """Utility method for waiting until the specified restore is no longer running.
+
+        :param timeout: The maximum time to wait for the restore to stop running. If the timeout is exceeded,
+                        an error is raised.
+        """
+        url = self.sesamapi_base_url + "restores/" + restore_id
+        starttime = time.monotonic()
+        while True:
+            try:
+                response = self.do_get_request(url, allowable_response_status_codes=[200], **kwargs)
+            except Exception:
+                # It is normal that the api stops responding during a restore, so we can ignore this
+                # exception unless we time out.
+                elapsedtime = time.monotonic() - starttime
+                if elapsedtime > timeout:
+                    raise
+                time.sleep(poll_interval)
+            restore_info = response.json()
+            if restore_info["status"] == "success":
+                return restore_info
+            elapsedtime = time.monotonic() - starttime
+            if elapsedtime > timeout:
+                raise TimeoutWhileWaitingForRestoreToFinishException(
+                    "Timed out while waiting for the restore to finish running! restore_info:\n%s" % (
+                        restore_info,))
 
             time.sleep(poll_interval)
 
