@@ -27,6 +27,8 @@ class TimeoutWhileWaitingForRunningIndexToFinishUpdatingException(Exception):
 class TimeoutWhileWaitingForBackupToFinishException(Exception):
     pass
 
+class TimeoutWhileWaitingForRestoreToFinishException(Exception):
+    pass
 
 class ExceptionWithResponse(Exception):
     def __init__(self, msg=None, response=None):
@@ -67,7 +69,7 @@ class PumpDoesNotSupportTheOperation(BadRequestException):
 
 class ConfigUploadFailed(BadRequestException):
     """This is raised when the server has responded with a 400 statuscode on a configuration upload request. The
-    reponse object is stored in the 'response' attribute. The json payload of the response is stored in the
+    response object is stored in the 'response' attribute. The json payload of the response is stored in the
     'parsed_response' attribute."""
     def __init__(self, msg=None, response=None):
         if response is not None:
